@@ -43,7 +43,8 @@ CursorType = Union[DictCursor, RealDictCursor, NamedTupleCursor]
 
 
 class PostgresHook(DbApiHook):
-    """Interact with Postgres.
+    """
+    Interact with Postgres.
 
     You can specify ssl parameters in the extra field of your connection
     as ``{"sslmode": "require", "sslcert": "/path/to/cert.pem", etc}``.
@@ -68,6 +69,10 @@ class PostgresHook(DbApiHook):
     :param options: Optional. Specifies command-line options to send to the server
         at connection start. For example, setting this to ``-c search_path=myschema``
         sets the session's value of the ``search_path`` to ``myschema``.
+    :param enable_log_db_messages: Optional. If enabled logs database messages sent to the client
+        during the session. To avoid a memory leak psycopg2 only saves the last 50 messages.
+        For details, see: `PostgreSQL logging configuration parameters
+        <https://www.postgresql.org/docs/current/runtime-config-logging.html>`__
     """
 
     conn_name_attr = "postgres_conn_id"
@@ -77,7 +82,9 @@ class PostgresHook(DbApiHook):
     supports_autocommit = True
     supports_executemany = True
 
-    def __init__(self, *args, options: str | None = None, **kwargs) -> None:
+    def __init__(
+        self, *args, options: str | None = None, enable_log_db_messages: bool = False, **kwargs
+    ) -> None:
         if "schema" in kwargs:
             warnings.warn(
                 'The "schema" arg has been renamed to "database" as it contained the database name.'
@@ -87,10 +94,10 @@ class PostgresHook(DbApiHook):
             )
             kwargs["database"] = kwargs["schema"]
         super().__init__(*args, **kwargs)
-        self.connection: Connection | None = kwargs.pop("connection", None)
         self.conn: connection = None
         self.database: str | None = kwargs.pop("database", None)
         self.options = options
+        self.enable_log_db_messages = enable_log_db_messages
 
     @property
     @deprecated(
@@ -116,7 +123,7 @@ class PostgresHook(DbApiHook):
 
     @property
     def sqlalchemy_url(self) -> URL:
-        conn = self.get_connection(getattr(self, self.conn_name_attr))
+        conn = self.get_connection(self.get_conn_id())
         return URL.create(
             drivername="postgresql",
             username=conn.login,
@@ -141,8 +148,7 @@ class PostgresHook(DbApiHook):
 
     def get_conn(self) -> connection:
         """Establish a connection to a postgres database."""
-        conn_id = getattr(self, self.conn_name_attr)
-        conn = deepcopy(self.connection or self.get_connection(conn_id))
+        conn = deepcopy(self.connection)
 
         # check for authentication via AWS IAM
         if conn.extra_dejson.get("iam", False):
@@ -176,7 +182,8 @@ class PostgresHook(DbApiHook):
         return self.conn
 
     def copy_expert(self, sql: str, filename: str) -> None:
-        """Execute SQL using psycopg2's ``copy_expert`` method.
+        """
+        Execute SQL using psycopg2's ``copy_expert`` method.
 
         Necessary to execute COPY command without access to a superuser.
 
@@ -197,7 +204,8 @@ class PostgresHook(DbApiHook):
             conn.commit()
 
     def get_uri(self) -> str:
-        """Extract the URI from the connection.
+        """
+        Extract the URI from the connection.
 
         :return: the extracted URI in Sqlalchemy URI format.
         """
@@ -213,7 +221,8 @@ class PostgresHook(DbApiHook):
 
     @staticmethod
     def _serialize_cell(cell: object, conn: connection | None = None) -> Any:
-        """Serialize a cell.
+        """
+        Serialize a cell.
 
         PostgreSQL adapts all arguments to the ``execute()`` method internally,
         hence we return the cell without any conversion.
@@ -228,7 +237,8 @@ class PostgresHook(DbApiHook):
         return cell
 
     def get_iam_token(self, conn: Connection) -> tuple[str, str, int]:
-        """Get the IAM token.
+        """
+        Get the IAM token.
 
         This uses AWSHook to retrieve a temporary password to connect to
         Postgres or Redshift. Port is required. If none is provided, the default
@@ -269,7 +279,8 @@ class PostgresHook(DbApiHook):
         return login, token, port
 
     def get_table_primary_key(self, table: str, schema: str | None = "public") -> list[str] | None:
-        """Get the table's primary key.
+        """
+        Get the table's primary key.
 
         :param table: Name of the target table
         :param schema: Name of the target schema, public by default
@@ -292,7 +303,8 @@ class PostgresHook(DbApiHook):
     def _generate_insert_sql(
         self, table: str, values: tuple[str, ...], target_fields: Iterable[str], replace: bool, **kwargs
     ) -> str:
-        """Generate the INSERT SQL statement.
+        """
+        Generate the INSERT SQL statement.
 
         The REPLACE variant is specific to the PostgreSQL syntax.
 
@@ -389,3 +401,13 @@ class PostgresHook(DbApiHook):
                 "schema": "Database",
             },
         }
+
+    def get_db_log_messages(self, conn) -> None:
+        """
+        Log all database messages sent to the client during the session.
+
+        :param conn: Connection object
+        """
+        if self.enable_log_db_messages:
+            for output in conn.notices:
+                self.log.info(output)
